Method: Gitlab::Client::Projects#project_forks

Defined in:
lib/gitlab/client/projects.rb

#project_forks(id, options = {}) ⇒ Array<Gitlab::ObjectifiedHash>

Get a list of all visible projects across GitLab for the authenticated user. When accessed without authentication, only public projects are returned.

Note: This feature was introduced in GitLab 10.1

Examples:

Gitlab.project_forks(42)

Parameters:

  • options (Hash) (defaults to: {})

    A customizable set of options.

Options Hash (options):

  • :page (Integer)

    The page number.

  • :per_page (Integer)

    The number of results per page.

  • :order_by (String)

    Return requests ordered by id, name, created_at or last_activity_at fields

  • :sort (String)

    Return requests sorted in asc or desc order

Returns:



456
457
458
# File 'lib/gitlab/client/projects.rb', line 456

def project_forks(id, options = {})
  get("/projects/#{url_encode id}/forks", query: options)
end