Method: Gitlab::ObjectifiedHash#inspect

Defined in:
lib/gitlab/objectified_hash.rb

#inspectString

Returns Formatted string with the class name, object id and original hash.

Returns:

  • (String)

    Formatted string with the class name, object id and original hash.



23
24
25
# File 'lib/gitlab/objectified_hash.rb', line 23

def inspect
  "#<#{self.class}:#{object_id} {hash: #{hash.inspect}}"
end