Method: Gitlab::Client::Projects#project_forks
- Defined in:
- lib/gitlab/client/projects.rb
#project_forks(id, options = {}) ⇒ Array<Gitlab::ObjectifiedHash>
Get a list of all visible projects across GitLab for the authenticated user. When accessed without authentication, only public projects are returned.
Note: This feature was introduced in GitLab 10.1
456 457 458 |
# File 'lib/gitlab/client/projects.rb', line 456 def project_forks(id, = {}) get("/projects/#{url_encode id}/forks", query: ) end |